env

package
v1.0.0-beta.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2024 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// Channel/Revision of the service snap (has default)
	EnvSnapChannel = "SNAP_CHANNEL"

	// Path to snap instead, used for testing a local snap instead of
	// downloading from the store
	EnvSnapPath = "SNAP_PATH"

	// Toggle the teardown operations during tests (has default)
	EnvTeardown = "TEARDOWN"
)

Environment variables, used to override defaults

Variables

This section is empty.

Functions

func SnapChannel

func SnapChannel() string

SnapChannel returns the set snap channel

func SnapPath

func SnapPath() string

SnapPath returns the set path to a local snap

func Teardown

func Teardown() (skip bool)

SkipTeardownRemoval return

Types

This section is empty.

Jump to